#!/usr/bin/env python3
# -*- coding: utf-8 -*-
from abc import ABC, abstractmethod

__author__ = "Christian Heider Nielsen"
__doc__ = r"""

           Created on 09/10/2019
           """
__all__ = ["ModuleParameterWriterMixin"]

import torch


class ModuleParameterWriterMixin(ABC):
    """
    Writer mixin that provides an interface for 'writing' torch Module parameters"""

    @abstractmethod
    def parameters(self, tag: str, model: torch.nn.Module, step: int, **kwargs) -> None:
        """

        :param tag:
        :type tag:
        :param model:
        :type model:
        :param step:
        :type step:
        :param kwargs:
        :type kwargs:"""
        raise NotImplementedError



def screen_res_gtk():
    import gtk

    screen = gtk.Window().get_screen()
    return screen.get_width(), screen.get_height()


def screen_res_tk():
    import Tkinter

    root = Tkinter.Tk()
    screen_width = root.winfo_screenwidth()
    screen_height = root.winfo_screenheight()
    return screen_width, screen_height


def screen_res():
    import ctypes.wintypes

    return ctypes.windll.user32.GetSystemMetrics(
        0
    ), ctypes.windll.user32.GetSystemMetrics(1)


def mac_res():
    try:
        import Quartz
    except:
        assert (
            False
        ), "You must first install pyobjc-core and pyobjc: MACOSX_DEPLOYMENT_TARGET=10.11 pip install pyobjc"
    main_disp_id = Quartz.CGMainDisplayID()
    return Quartz.CGDisplayPixelsWide(main_disp_id), Quartz.CGDisplayPixelsHigh(
        main_disp_id
    )
